tcp

package
v7.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

func NewClient

func NewClient(cfg *ngrok.ClientConfig) *Client

func (*Client) Create

func (c *Client) Create(ctx context.Context, arg *ngrok.TCPEdgeCreate) (*ngrok.TCPEdge, error)

Create a TCP Edge

https://ngrok.com/docs/api#api-edges-tcp-create

func (*Client) Delete

func (c *Client) Delete(ctx context.Context, id string) error

Delete a TCP Edge by ID

https://ngrok.com/docs/api#api-edges-tcp-delete

func (*Client) Get

func (c *Client) Get(ctx context.Context, id string) (*ngrok.TCPEdge, error)

Get a TCP Edge by ID

https://ngrok.com/docs/api#api-edges-tcp-get

func (*Client) List

func (c *Client) List(paging *ngrok.Paging) ngrok.Iter[*ngrok.TCPEdge]

Returns a list of all TCP Edges on this account

https://ngrok.com/docs/api#api-edges-tcp-list

func (*Client) Update

func (c *Client) Update(ctx context.Context, arg *ngrok.TCPEdgeUpdate) (*ngrok.TCPEdge, error)

Updates a TCP Edge by ID. If a module is not specified in the update, it will not be modified. However, each module configuration that is specified will completely replace the existing value. There is no way to delete an existing module via this API, instead use the delete module API.

https://ngrok.com/docs/api#api-edges-tcp-update

Jump to